DPDK patches and discussions
 help / color / mirror / Atom feed
From: Bing Zhao <bingz@nvidia.com>
To: <viacheslavo@nvidia.com>, <matan@nvidia.com>, <thomas@monjalon.net>
Cc: <dev@dpdk.org>, <orika@nvidia.com>, <rasland@nvidia.com>
Subject: [dpdk-dev] [PATCH v3 16/17] net/mlx5: add support of CT between two ports
Date: Wed, 5 May 2021 09:50:07 +0300	[thread overview]
Message-ID: <20210505065008.30680-17-bingz@nvidia.com> (raw)
In-Reply-To: <20210505065008.30680-1-bingz@nvidia.com>

After creating a connection tracking context, it can be used between
two ports. For each port, the flow for one direction traffic will
be created.

The context can only be shared between the owner port and the peer
port that was specified when being created. Only the owner port
could update the context or query it in current implementation.

Signed-off-by: Bing Zhao <bingz@nvidia.com>
---
 drivers/net/mlx5/mlx5_flow.h    | 57 +++++++++++++++++++++++++-
 drivers/net/mlx5/mlx5_flow_dv.c | 71 +++++++++++++++++++++++++--------
 2 files changed, 110 insertions(+), 18 deletions(-)

diff --git a/drivers/net/mlx5/mlx5_flow.h b/drivers/net/mlx5/mlx5_flow.h
index 238befa2d4..ddaba40f72 100644
--- a/drivers/net/mlx5/mlx5_flow.h
+++ b/drivers/net/mlx5/mlx5_flow.h
@@ -48,6 +48,25 @@ enum {
 	MLX5_INDIRECT_ACTION_TYPE_CT,
 };
 
+/* Now, the maximal ports will be supported is 256, action number is 4M. */
+#define MLX5_INDIRECT_ACT_CT_MAX_PORT 0x100
+
+#define MLX5_INDIRECT_ACT_CT_OWNER_SHIFT 22
+#define MLX5_INDIRECT_ACT_CT_OWNER_MASK (MLX5_INDIRECT_ACT_CT_MAX_PORT - 1)
+
+/* 30-31: type, 22-29: owner port, 0-21: index. */
+#define MLX5_INDIRECT_ACT_CT_GEN_IDX(owner, index) \
+	((MLX5_INDIRECT_ACTION_TYPE_CT << MLX5_INDIRECT_ACTION_TYPE_OFFSET) | \
+	 (((owner) & MLX5_INDIRECT_ACT_CT_OWNER_MASK) << \
+	  MLX5_INDIRECT_ACT_CT_OWNER_SHIFT) | (index))
+
+#define MLX5_INDIRECT_ACT_CT_GET_OWNER(index) \
+	(((index) >> MLX5_INDIRECT_ACT_CT_OWNER_SHIFT) & \
+	 MLX5_INDIRECT_ACT_CT_OWNER_MASK)
+
+#define MLX5_INDIRECT_ACT_CT_GET_IDX(index) \
+	((index) & ((1 << MLX5_INDIRECT_ACT_CT_OWNER_SHIFT) - 1))
+
 /* Matches on selected register. */
 struct mlx5_rte_flow_item_tag {
 	enum modify_reg id;
@@ -1304,7 +1323,7 @@ mlx5_aso_meter_by_idx(struct mlx5_priv *priv, uint32_t idx)
 }
 
 /*
- * Get ASO CT action by index.
+ * Get ASO CT action by device and index.
  *
  * @param[in] dev
  *   Pointer to the Ethernet device structure.
@@ -1315,7 +1334,7 @@ mlx5_aso_meter_by_idx(struct mlx5_priv *priv, uint32_t idx)
  *   The specified ASO CT action pointer.
  */
 static inline struct mlx5_aso_ct_action *
-flow_aso_ct_get_by_idx(struct rte_eth_dev *dev, uint32_t idx)
+flow_aso_ct_get_by_dev_idx(struct rte_eth_dev *dev, uint32_t idx)
 {
 	struct mlx5_priv *priv = dev->data->dev_private;
 	struct mlx5_aso_ct_pools_mng *mng = priv->sh->ct_mng;
@@ -1330,6 +1349,40 @@ flow_aso_ct_get_by_idx(struct rte_eth_dev *dev, uint32_t idx)
 	return &pool->actions[idx % MLX5_ASO_CT_ACTIONS_PER_POOL];
 }
 
+/*
+ * Get ASO CT action by owner & index.
+ *
+ * @param[in] dev
+ *   Pointer to the Ethernet device structure.
+ * @param[in] idx
+ *   Index to the ASO CT action and owner port combination.
+ *
+ * @return
+ *   The specified ASO CT action pointer.
+ */
+static inline struct mlx5_aso_ct_action *
+flow_aso_ct_get_by_idx(struct rte_eth_dev *dev, uint32_t own_idx)
+{
+	struct mlx5_priv *priv = dev->data->dev_private;
+	struct mlx5_aso_ct_action *ct;
+	uint16_t owner = (uint16_t)MLX5_INDIRECT_ACT_CT_GET_OWNER(own_idx);
+	uint32_t idx = MLX5_INDIRECT_ACT_CT_GET_IDX(own_idx);
+
+	if (owner == PORT_ID(priv)) {
+		ct = flow_aso_ct_get_by_dev_idx(dev, idx);
+	} else {
+		struct rte_eth_dev *owndev = &rte_eth_devices[owner];
+
+		MLX5_ASSERT(owner < RTE_MAX_ETHPORTS);
+		if (dev->data->dev_started != 1)
+			return NULL;
+		ct = flow_aso_ct_get_by_dev_idx(owndev, idx);
+		if (ct->peer != PORT_ID(priv))
+			return NULL;
+	}
+	return ct;
+}
+
 int mlx5_flow_group_to_table(struct rte_eth_dev *dev,
 			     const struct mlx5_flow_tunnel *tunnel,
 			     uint32_t group, uint32_t *table,
diff --git a/drivers/net/mlx5/mlx5_flow_dv.c b/drivers/net/mlx5/mlx5_flow_dv.c
index aa0a5acdca..ca55cff48b 100644
--- a/drivers/net/mlx5/mlx5_flow_dv.c
+++ b/drivers/net/mlx5/mlx5_flow_dv.c
@@ -11289,7 +11289,7 @@ flow_dv_translate_create_aso_age(struct rte_eth_dev *dev,
 }
 
 /*
  * Release an ASO CT action.
  *
  * @param[in] dev
  *   Pointer to the Ethernet device structure.
@@ -11300,12 +11300,12 @@ flow_dv_translate_create_aso_age(struct rte_eth_dev *dev,
  *   0 when CT action was removed, otherwise the number of references.
  */
 static inline int
-flow_dv_aso_ct_release(struct rte_eth_dev *dev, uint32_t idx)
+flow_dv_aso_ct_dev_release(struct rte_eth_dev *dev, uint32_t idx)
 {
 	struct mlx5_priv *priv = dev->data->dev_private;
 	struct mlx5_aso_ct_pools_mng *mng = priv->sh->ct_mng;
 	uint32_t ret;
-	struct mlx5_aso_ct_action *ct = flow_aso_ct_get_by_idx(dev, idx);
+	struct mlx5_aso_ct_action *ct = flow_aso_ct_get_by_dev_idx(dev, idx);
 	enum mlx5_aso_ct_state state =
 			__atomic_load_n(&ct->state, __ATOMIC_RELAXED);
 
@@ -11334,7 +11334,21 @@ flow_dv_aso_ct_release(struct rte_eth_dev *dev, uint32_t idx)
 		LIST_INSERT_HEAD(&mng->free_cts, ct, next);
 		rte_spinlock_unlock(&mng->ct_sl);
 	}
-	return ret;
+	return (int)ret;
+}
+
+static inline int
+flow_dv_aso_ct_release(struct rte_eth_dev *dev, uint32_t own_idx)
+{
+	uint16_t owner = (uint16_t)MLX5_INDIRECT_ACT_CT_GET_OWNER(own_idx);
+	uint32_t idx = MLX5_INDIRECT_ACT_CT_GET_IDX(own_idx);
+	struct rte_eth_dev *owndev = &rte_eth_devices[owner];
+	RTE_SET_USED(dev);
+
+	MLX5_ASSERT(owner < RTE_MAX_ETHPORTS);
+	if (dev->data->dev_started != 1)
+		return -1;
+	return flow_dv_aso_ct_dev_release(owndev, idx);
 }
 
 /*
@@ -11486,7 +11500,7 @@ flow_dv_aso_ct_alloc(struct rte_eth_dev *dev, struct rte_flow_error *error)
 		RTE_SET_USED(reg_c);
 #endif
 		if (!ct->dr_action_orig) {
-			flow_dv_aso_ct_release(dev, ct_idx);
+			flow_dv_aso_ct_dev_release(dev, ct_idx);
 			rte_flow_error_set(error, rte_errno,
 					   RTE_FLOW_ERROR_TYPE_ACTION, NULL,
 					   "failed to create ASO CT action");
@@ -11502,7 +11516,7 @@ flow_dv_aso_ct_alloc(struct rte_eth_dev *dev, struct rte_flow_error *error)
 			 reg_c - REG_C_0);
 #endif
 		if (!ct->dr_action_rply) {
-			flow_dv_aso_ct_release(dev, ct_idx);
+			flow_dv_aso_ct_dev_release(dev, ct_idx);
 			rte_flow_error_set(error, rte_errno,
 					   RTE_FLOW_ERROR_TYPE_ACTION, NULL,
 					   "failed to create ASO CT action");
@@ -11544,12 +11558,13 @@ flow_dv_translate_create_conntrack(struct rte_eth_dev *dev,
 		return rte_flow_error_set(error, rte_errno,
 					  RTE_FLOW_ERROR_TYPE_ACTION, NULL,
 					  "Failed to allocate CT object");
-	ct = flow_aso_ct_get_by_idx(dev, idx);
+	ct = flow_aso_ct_get_by_dev_idx(dev, idx);
 	if (mlx5_aso_ct_update_by_wqe(sh, ct, pro))
 		return rte_flow_error_set(error, EBUSY,
 					  RTE_FLOW_ERROR_TYPE_ACTION, NULL,
 					  "Failed to update CT");
 	ct->is_original = !!pro->is_original_dir;
+	ct->peer = pro->peer_port;
 	return idx;
 }
 
@@ -11713,7 +11728,7 @@ flow_dv_translate(struct rte_eth_dev *dev,
 		const struct rte_flow_action *found_action = NULL;
 		uint32_t jump_group = 0;
 		struct mlx5_flow_counter *cnt;
-		uint32_t ct_idx;
+		uint32_t owner_idx;
 		struct mlx5_aso_ct_action *ct;
 
 		if (!mlx5_flow_os_action_supported(action_type))
@@ -12189,8 +12204,13 @@ flow_dv_translate(struct rte_eth_dev *dev,
 			action_flags |= MLX5_FLOW_ACTION_MODIFY_FIELD;
 			break;
 		case RTE_FLOW_ACTION_TYPE_CONNTRACK:
-			ct_idx = (uint32_t)(uintptr_t)action->conf;
-			ct = flow_aso_ct_get_by_idx(dev, ct_idx);
+			owner_idx = (uint32_t)(uintptr_t)action->conf;
+			ct = flow_aso_ct_get_by_idx(dev, owner_idx);
+			if (!ct)
+				return rte_flow_error_set(error, EINVAL,
+						RTE_FLOW_ERROR_TYPE_ACTION,
+						NULL,
+						"Failed to get CT object.");
 			if (mlx5_aso_ct_available(priv->sh, ct))
 				return rte_flow_error_set(error, rte_errno,
 						RTE_FLOW_ERROR_TYPE_ACTION,
@@ -12203,7 +12223,7 @@ flow_dv_translate(struct rte_eth_dev *dev,
 				dev_flow->dv.actions[actions_n] =
 							ct->dr_action_rply;
 			flow->indirect_type = MLX5_INDIRECT_ACTION_TYPE_CT;
-			flow->ct = ct_idx;
+			flow->ct = owner_idx;
 			__atomic_fetch_add(&ct->refcnt, 1, __ATOMIC_RELAXED);
 			actions_n++;
 			action_flags |= MLX5_FLOW_ACTION_CT;
@@ -13803,8 +13823,7 @@ flow_dv_action_create(struct rte_eth_dev *dev,
 	case RTE_FLOW_ACTION_TYPE_CONNTRACK:
 		ret = flow_dv_translate_create_conntrack(dev, action->conf,
 							 err);
-		idx = (MLX5_INDIRECT_ACTION_TYPE_CT <<
-		       MLX5_INDIRECT_ACTION_TYPE_OFFSET) | ret;
+		idx = MLX5_INDIRECT_ACT_CT_GEN_IDX(PORT_ID(priv), ret);
 		break;
 	default:
 		rte_flow_error_set(err, ENOTSUP, RTE_FLOW_ERROR_TYPE_ACTION,
@@ -13856,7 +13875,9 @@ flow_dv_action_destroy(struct rte_eth_dev *dev,
 		return 0;
 	case MLX5_INDIRECT_ACTION_TYPE_CT:
 		ret = flow_dv_aso_ct_release(dev, idx);
-		if (ret)
+		if (ret < 0)
+			return ret;
+		if (ret > 0)
 			DRV_LOG(DEBUG, "Connection tracking object %u still "
 				"has references %d.", idx, ret);
 		return 0;
@@ -13960,8 +13981,16 @@ __flow_dv_action_ct_update(struct rte_eth_dev *dev, uint32_t idx,
 	struct mlx5_aso_ct_action *ct;
 	const struct rte_flow_action_conntrack *new_prf;
 	int ret = 0;
+	uint16_t owner = (uint16_t)MLX5_INDIRECT_ACT_CT_GET_OWNER(idx);
+	uint32_t dev_idx;
 
-	ct = flow_aso_ct_get_by_idx(dev, idx);
+	if (PORT_ID(priv) != owner)
+		return rte_flow_error_set(error, EACCES,
+					  RTE_FLOW_ERROR_TYPE_UNSPECIFIED,
+					  NULL,
+					  "CT object owned by another port");
+	dev_idx = MLX5_INDIRECT_ACT_CT_GET_IDX(idx);
+	ct = flow_aso_ct_get_by_dev_idx(dev, dev_idx);
 	if (!ct->refcnt)
 		return rte_flow_error_set(error, ENOMEM,
 					  RTE_FLOW_ERROR_TYPE_UNSPECIFIED,
@@ -14049,6 +14078,8 @@ flow_dv_action_query(struct rte_eth_dev *dev,
 	uint32_t idx = act_idx & ((1u << MLX5_INDIRECT_ACTION_TYPE_OFFSET) - 1);
 	struct mlx5_priv *priv = dev->data->dev_private;
 	struct mlx5_aso_ct_action *ct;
+	uint16_t owner;
+	uint32_t dev_idx;
 
 	switch (type) {
 	case MLX5_INDIRECT_ACTION_TYPE_AGE:
@@ -14063,7 +14094,15 @@ flow_dv_action_query(struct rte_eth_dev *dev,
 			     (&age_param->sec_since_last_hit, __ATOMIC_RELAXED);
 		return 0;
 	case MLX5_INDIRECT_ACTION_TYPE_CT:
-		ct = flow_aso_ct_get_by_idx(dev, idx);
+		owner = (uint16_t)MLX5_INDIRECT_ACT_CT_GET_OWNER(idx);
+		if (owner != PORT_ID(priv))
+			return rte_flow_error_set(error, EACCES,
+					RTE_FLOW_ERROR_TYPE_UNSPECIFIED,
+					NULL,
+					"CT object owned by another port");
+		dev_idx = MLX5_INDIRECT_ACT_CT_GET_IDX(idx);
+		ct = flow_aso_ct_get_by_dev_idx(dev, dev_idx);
+		MLX5_ASSERT(ct);
 		if (!ct->refcnt)
 			return rte_flow_error_set(error, EFAULT,
 					RTE_FLOW_ERROR_TYPE_UNSPECIFIED,
@@ -11289,7 +11289,7 @@ flow_dv_translate_create_aso_age(struct rte_eth_dev *dev,
 
 /*
- * Release an ASO CT action.
+ * Release an ASO CT action by its own device.
  *
  * @param[in] dev
-- 
2.27.0


  parent reply	other threads:[~2021-05-05  6:53 UTC|newest]

Thread overview: 147+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2021-04-27 15:37 [dpdk-dev] [PATCH 00/17] conntrack support in mlx5 PMD Bing Zhao
2021-04-27 15:37 ` [dpdk-dev] [PATCH 01/17] common/mlx5: add connection tracking object definition Bing Zhao
2021-04-27 15:37 ` [dpdk-dev] [PATCH 02/17] common/mlx5: add CT offload capability checking Bing Zhao
2021-04-27 15:37 ` [dpdk-dev] [PATCH 03/17] net/mlx5: use meter color reg for CT Bing Zhao
2021-04-27 15:37 ` [dpdk-dev] [PATCH 04/17] net/mlx5: initialization of CT management Bing Zhao
2021-04-27 15:37 ` [dpdk-dev] [PATCH 05/17] common/mlx5: add Dexv CT objects creation Bing Zhao
2021-04-27 15:38 ` [dpdk-dev] [PATCH 06/17] net/mlx5: add modify support for CT Bing Zhao
2021-04-27 15:38 ` [dpdk-dev] [PATCH 07/17] net/mlx5: add actions creating " Bing Zhao
2021-04-27 15:38 ` [dpdk-dev] [PATCH 08/17] net/mlx5: close CT management structure Bing Zhao
2021-04-27 15:38 ` [dpdk-dev] [PATCH 09/17] net/mlx5: add ASO CT query implementation Bing Zhao
2021-04-27 15:38 ` [dpdk-dev] [PATCH 10/17] net/mlx5: add ASO CT destroy handling Bing Zhao
2021-04-27 15:38 ` [dpdk-dev] [PATCH 11/17] net/mlx5: add translation for CT action Bing Zhao
2021-04-27 15:38 ` [dpdk-dev] [PATCH 12/17] net/mlx5: add translation of CT item Bing Zhao
2021-04-27 15:38 ` [dpdk-dev] [PATCH 13/17] net/mlx5: add CT context update Bing Zhao
2021-04-27 15:38 ` [dpdk-dev] [PATCH 14/17] net/mlx5: validation of CT action Bing Zhao
2021-04-27 15:38 ` [dpdk-dev] [PATCH 15/17] net/mlx5: validation of CT item Bing Zhao
2021-04-27 15:38 ` [dpdk-dev] [PATCH 16/17] net/mlx5: reduce the reference count of CT Bing Zhao
2021-04-27 15:38 ` [dpdk-dev] [PATCH 17/17] net/mlx5: add support of CT between two ports Bing Zhao
2021-05-05  4:19 ` [dpdk-dev] [PATCH v2 00/17] conntrack support in mlx5 PMD Bing Zhao
2021-05-05  4:19   ` [dpdk-dev] [PATCH v2 01/17] common/mlx5: add connection tracking object definition Bing Zhao
2021-05-05  4:19   ` [dpdk-dev] [PATCH v2 02/17] common/mlx5: add CT offload capability checking Bing Zhao
2021-05-05  4:19   ` [dpdk-dev] [PATCH v2 03/17] net/mlx5: use meter color reg for CT Bing Zhao
2021-05-05  4:19   ` [dpdk-dev] [PATCH v2 04/17] net/mlx5: initialization of CT management Bing Zhao
2021-05-05  4:19   ` [dpdk-dev] [PATCH v2 05/17] common/mlx5: add Dexv CT objects creation Bing Zhao
2021-05-05  4:19   ` [dpdk-dev] [PATCH v2 06/17] net/mlx5: add modify support for CT Bing Zhao
2021-05-05  4:19   ` [dpdk-dev] [PATCH v2 07/17] net/mlx5: add actions creating " Bing Zhao
2021-05-05  4:19   ` [dpdk-dev] [PATCH v2 08/17] net/mlx5: close CT management structure Bing Zhao
2021-05-05  4:19   ` [dpdk-dev] [PATCH v2 09/17] net/mlx5: add ASO CT query implementation Bing Zhao
2021-05-05  4:19   ` [dpdk-dev] [PATCH v2 10/17] net/mlx5: add ASO CT destroy handling Bing Zhao
2021-05-05  4:19   ` [dpdk-dev] [PATCH v2 11/17] net/mlx5: add translation of CT action Bing Zhao
2021-05-05  4:19   ` [dpdk-dev] [PATCH v2 12/17] net/mlx5: add translation of CT item Bing Zhao
2021-05-05  4:20   ` [dpdk-dev] [PATCH v2 13/17] net/mlx5: add CT context update Bing Zhao
2021-05-05  4:20   ` [dpdk-dev] [PATCH v2 14/17] net/mlx5: validation of CT action Bing Zhao
2021-05-05  4:20   ` [dpdk-dev] [PATCH v2 15/17] net/mlx5: validation of CT item Bing Zhao
2021-05-05  4:20   ` [dpdk-dev] [PATCH v2 16/17] net/mlx5: add support of CT between two ports Bing Zhao
2021-05-05  4:20   ` [dpdk-dev] [PATCH v2 17/17] doc: update mlx5 support for conntrack Bing Zhao
2021-05-05  6:05   ` [dpdk-dev] [PATCH v2 00/17] conntrack support in mlx5 PMD Slava Ovsiienko
2021-05-05  6:40 ` [dpdk-dev] [PATCH v3 " Bing Zhao
2021-05-05  6:40   ` [dpdk-dev] [PATCH v3 01/17] common/mlx5: add connection tracking object definition Bing Zhao
2021-05-05  6:40   ` [dpdk-dev] [PATCH v3 02/17] common/mlx5: add CT offload capability checking Bing Zhao
2021-05-05  6:40   ` [dpdk-dev] [PATCH v3 03/17] net/mlx5: use meter color reg for CT Bing Zhao
2021-05-05  6:40   ` [dpdk-dev] [PATCH v3 04/17] net/mlx5: initialization of CT management Bing Zhao
2021-05-05  6:40   ` [dpdk-dev] [PATCH v3 05/17] common/mlx5: add Dexv CT objects creation Bing Zhao
2021-05-05  6:40   ` [dpdk-dev] [PATCH v3 06/17] net/mlx5: add modify support for CT Bing Zhao
2021-05-05  6:40   ` [dpdk-dev] [PATCH v3 07/17] net/mlx5: add actions creating " Bing Zhao
2021-05-05  6:40   ` [dpdk-dev] [PATCH v3 08/17] net/mlx5: close CT management structure Bing Zhao
2021-05-05  6:40   ` [dpdk-dev] [PATCH v3 09/17] net/mlx5: add ASO CT query implementation Bing Zhao
2021-05-05  6:40   ` [dpdk-dev] [PATCH v3 10/17] net/mlx5: add ASO CT destroy handling Bing Zhao
2021-05-05  6:40   ` [dpdk-dev] [PATCH v3 11/17] net/mlx5: add translation of CT action Bing Zhao
2021-05-05  6:40   ` [dpdk-dev] [PATCH v3 12/17] net/mlx5: add translation of CT item Bing Zhao
2021-05-05  6:41   ` [dpdk-dev] [PATCH v3 13/17] net/mlx5: add CT context update Bing Zhao
2021-05-05  6:41   ` [dpdk-dev] [PATCH v3 14/17] net/mlx5: validation of CT action Bing Zhao
2021-05-05  6:41   ` [dpdk-dev] [PATCH v3 15/17] net/mlx5: validation of CT item Bing Zhao
2021-05-05  6:41   ` [dpdk-dev] [PATCH v3 16/17] net/mlx5: add support of CT between two ports Bing Zhao
2021-05-05  6:49 ` [dpdk-dev] [PATCH v3 00/17] conntrack support in mlx5 PMD Bing Zhao
2021-05-05  6:49   ` [dpdk-dev] [PATCH v3 01/17] common/mlx5: add connection tracking object definition Bing Zhao
2021-05-05  6:49   ` [dpdk-dev] [PATCH v3 02/17] common/mlx5: add CT offload capability checking Bing Zhao
2021-05-05  6:49   ` [dpdk-dev] [PATCH v3 03/17] net/mlx5: use meter color reg for CT Bing Zhao
2021-05-05  6:49   ` [dpdk-dev] [PATCH v3 04/17] net/mlx5: initialization of CT management Bing Zhao
2021-05-05  6:49   ` [dpdk-dev] [PATCH v3 05/17] common/mlx5: add Dexv CT objects creation Bing Zhao
2021-05-05  6:49   ` [dpdk-dev] [PATCH v3 06/17] net/mlx5: add modify support for CT Bing Zhao
2021-05-05  6:49   ` [dpdk-dev] [PATCH v3 07/17] net/mlx5: add actions creating " Bing Zhao
2021-05-05  6:49   ` [dpdk-dev] [PATCH v3 08/17] net/mlx5: close CT management structure Bing Zhao
2021-05-05  6:50   ` [dpdk-dev] [PATCH v3 09/17] net/mlx5: add ASO CT query implementation Bing Zhao
2021-05-05  6:50   ` [dpdk-dev] [PATCH v3 10/17] net/mlx5: add ASO CT destroy handling Bing Zhao
2021-05-05  6:50   ` [dpdk-dev] [PATCH v3 11/17] net/mlx5: add translation of CT action Bing Zhao
2021-05-05  6:50   ` [dpdk-dev] [PATCH v3 12/17] net/mlx5: add translation of CT item Bing Zhao
2021-05-05  6:50   ` [dpdk-dev] [PATCH v3 13/17] net/mlx5: add CT context update Bing Zhao
2021-05-05  6:50   ` [dpdk-dev] [PATCH v3 14/17] net/mlx5: validation of CT action Bing Zhao
2021-05-05  6:50   ` [dpdk-dev] [PATCH v3 15/17] net/mlx5: validation of CT item Bing Zhao
2021-05-05  6:50   ` Bing Zhao [this message]
2021-05-05  6:50   ` [dpdk-dev] [PATCH v3 17/17] doc: update mlx5 support for conntrack Bing Zhao
2021-05-05  7:19 ` [dpdk-dev] [PATCH v4 00/17] conntrack support in mlx5 PMD Bing Zhao
2021-05-05  7:19   ` [dpdk-dev] [PATCH v4 01/17] common/mlx5: add connection tracking object definition Bing Zhao
2021-05-05  7:19   ` [dpdk-dev] [PATCH v4 02/17] common/mlx5: add CT offload capability checking Bing Zhao
2021-05-05  7:19   ` [dpdk-dev] [PATCH v4 03/17] net/mlx5: use meter color reg for CT Bing Zhao
2021-05-05  7:19   ` [dpdk-dev] [PATCH v4 04/17] net/mlx5: initialization of CT management Bing Zhao
2021-05-05  7:19   ` [dpdk-dev] [PATCH v4 05/17] common/mlx5: add Dexv CT objects creation Bing Zhao
2021-05-05  7:19   ` [dpdk-dev] [PATCH v4 06/17] net/mlx5: add modify support for CT Bing Zhao
2021-05-05  7:19   ` [dpdk-dev] [PATCH v4 07/17] net/mlx5: add actions creating " Bing Zhao
2021-05-05  7:19   ` [dpdk-dev] [PATCH v4 08/17] net/mlx5: close CT management structure Bing Zhao
2021-05-05  7:19   ` [dpdk-dev] [PATCH v4 09/17] net/mlx5: add ASO CT query implementation Bing Zhao
2021-05-05  7:19   ` [dpdk-dev] [PATCH v4 10/17] net/mlx5: add ASO CT destroy handling Bing Zhao
2021-05-05  7:19   ` [dpdk-dev] [PATCH v4 11/17] net/mlx5: add translation of CT action Bing Zhao
2021-05-05  7:19   ` [dpdk-dev] [PATCH v4 12/17] net/mlx5: add translation of CT item Bing Zhao
2021-05-05  7:19   ` [dpdk-dev] [PATCH v4 13/17] net/mlx5: add CT context update Bing Zhao
2021-05-05  7:19   ` [dpdk-dev] [PATCH v4 14/17] net/mlx5: validation of CT action Bing Zhao
2021-05-05  7:19   ` [dpdk-dev] [PATCH v4 15/17] net/mlx5: validation of CT item Bing Zhao
2021-05-05  7:19   ` [dpdk-dev] [PATCH v4 16/17] net/mlx5: add support of CT between two ports Bing Zhao
2021-05-05  7:19   ` [dpdk-dev] [PATCH v4 17/17] doc: update mlx5 support for conntrack Bing Zhao
2021-05-05  8:05 ` [dpdk-dev] [PATCH v5 00/17] conntrack support in mlx5 PMD Bing Zhao
2021-05-05  8:05   ` [dpdk-dev] [PATCH v5 01/17] common/mlx5: add connection tracking object definition Bing Zhao
2021-05-05  8:05   ` [dpdk-dev] [PATCH v5 02/17] common/mlx5: add CT offload capability checking Bing Zhao
2021-05-05  8:05   ` [dpdk-dev] [PATCH v5 03/17] net/mlx5: use meter color reg for CT Bing Zhao
2021-05-05  8:05   ` [dpdk-dev] [PATCH v5 04/17] net/mlx5: initialization of CT management Bing Zhao
2021-05-05  8:05   ` [dpdk-dev] [PATCH v5 05/17] common/mlx5: add Dexv CT objects creation Bing Zhao
2021-05-05  8:05   ` [dpdk-dev] [PATCH v5 06/17] net/mlx5: add modify support for CT Bing Zhao
2021-05-05  8:05   ` [dpdk-dev] [PATCH v5 07/17] net/mlx5: add actions creating " Bing Zhao
2021-05-05  8:05   ` [dpdk-dev] [PATCH v5 08/17] net/mlx5: close CT management structure Bing Zhao
2021-05-05  8:05   ` [dpdk-dev] [PATCH v5 09/17] net/mlx5: add ASO CT query implementation Bing Zhao
2021-05-05  8:05   ` [dpdk-dev] [PATCH v5 10/17] net/mlx5: add ASO CT destroy handling Bing Zhao
2021-05-05  8:05   ` [dpdk-dev] [PATCH v5 11/17] net/mlx5: add translation of CT action Bing Zhao
2021-05-05  8:05   ` [dpdk-dev] [PATCH v5 12/17] net/mlx5: add translation of CT item Bing Zhao
2021-05-05  8:05   ` [dpdk-dev] [PATCH v5 13/17] net/mlx5: add CT context update Bing Zhao
2021-05-05  8:05   ` [dpdk-dev] [PATCH v5 14/17] net/mlx5: validation of CT action Bing Zhao
2021-05-05  8:05   ` [dpdk-dev] [PATCH v5 15/17] net/mlx5: validation of CT item Bing Zhao
2021-05-05  8:05   ` [dpdk-dev] [PATCH v5 16/17] net/mlx5: add support of CT between two ports Bing Zhao
2021-05-05  8:06   ` [dpdk-dev] [PATCH v5 17/17] doc: update mlx5 support for conntrack Bing Zhao
2021-05-05  9:49 ` [dpdk-dev] [PATCH v6 00/17] conntrack support in mlx5 PMD Bing Zhao
2021-05-05  9:49   ` [dpdk-dev] [PATCH v6 01/17] common/mlx5: add connection tracking object definition Bing Zhao
2021-05-05  9:49   ` [dpdk-dev] [PATCH v6 02/17] common/mlx5: add CT offload capability checking Bing Zhao
2021-05-05  9:49   ` [dpdk-dev] [PATCH v6 03/17] net/mlx5: use meter color reg for CT Bing Zhao
2021-05-05  9:49   ` [dpdk-dev] [PATCH v6 04/17] net/mlx5: initialization of CT management Bing Zhao
2021-05-05  9:49   ` [dpdk-dev] [PATCH v6 05/17] common/mlx5: add Dexv CT objects creation Bing Zhao
2021-05-05  9:49   ` [dpdk-dev] [PATCH v6 06/17] net/mlx5: add modify support for CT Bing Zhao
2021-05-05  9:49   ` [dpdk-dev] [PATCH v6 07/17] net/mlx5: add actions creating " Bing Zhao
2021-05-05  9:50   ` [dpdk-dev] [PATCH v6 08/17] net/mlx5: close CT management structure Bing Zhao
2021-05-05  9:50   ` [dpdk-dev] [PATCH v6 09/17] net/mlx5: add ASO CT query implementation Bing Zhao
2021-05-05  9:50   ` [dpdk-dev] [PATCH v6 10/17] net/mlx5: add ASO CT destroy handling Bing Zhao
2021-05-05  9:50   ` [dpdk-dev] [PATCH v6 11/17] net/mlx5: add translation of CT action Bing Zhao
2021-05-05  9:50   ` [dpdk-dev] [PATCH v6 12/17] net/mlx5: add translation of CT item Bing Zhao
2021-05-05  9:50   ` [dpdk-dev] [PATCH v6 13/17] net/mlx5: add CT context update Bing Zhao
2021-05-05  9:50   ` [dpdk-dev] [PATCH v6 14/17] net/mlx5: validation of CT action Bing Zhao
2021-05-05  9:50   ` [dpdk-dev] [PATCH v6 15/17] net/mlx5: validation of CT item Bing Zhao
2021-05-05  9:50   ` [dpdk-dev] [PATCH v6 16/17] net/mlx5: add support of CT between two ports Bing Zhao
2021-05-05  9:50   ` [dpdk-dev] [PATCH v6 17/17] doc: update mlx5 support for conntrack Bing Zhao
2021-05-05 12:23 ` [dpdk-dev] [PATCH v7 00/17] conntrack support in mlx5 PMD Bing Zhao
2021-05-05 12:23   ` [dpdk-dev] [PATCH v7 01/17] common/mlx5: add connection tracking object definition Bing Zhao
2021-05-05 12:23   ` [dpdk-dev] [PATCH v7 02/17] common/mlx5: add CT offload capability checking Bing Zhao
2021-05-05 12:23   ` [dpdk-dev] [PATCH v7 03/17] net/mlx5: use meter color reg for CT Bing Zhao
2021-05-05 12:23   ` [dpdk-dev] [PATCH v7 04/17] net/mlx5: initialization of CT management Bing Zhao
2021-05-05 12:23   ` [dpdk-dev] [PATCH v7 05/17] common/mlx5: add Dexv CT objects creation Bing Zhao
2021-05-05 12:23   ` [dpdk-dev] [PATCH v7 06/17] net/mlx5: add modify support for CT Bing Zhao
2021-05-05 12:23   ` [dpdk-dev] [PATCH v7 07/17] net/mlx5: add actions creating " Bing Zhao
2021-05-05 12:23   ` [dpdk-dev] [PATCH v7 08/17] net/mlx5: close CT management structure Bing Zhao
2021-05-05 12:23   ` [dpdk-dev] [PATCH v7 09/17] net/mlx5: add ASO CT query implementation Bing Zhao
2021-05-05 12:23   ` [dpdk-dev] [PATCH v7 10/17] net/mlx5: add ASO CT destroy handling Bing Zhao
2021-05-05 12:23   ` [dpdk-dev] [PATCH v7 11/17] net/mlx5: add translation of CT action Bing Zhao
2021-05-05 12:23   ` [dpdk-dev] [PATCH v7 12/17] net/mlx5: add translation of CT item Bing Zhao
2021-05-05 12:23   ` [dpdk-dev] [PATCH v7 13/17] net/mlx5: add CT context update Bing Zhao
2021-05-05 12:23   ` [dpdk-dev] [PATCH v7 14/17] net/mlx5: validation of CT action Bing Zhao
2021-05-05 12:23   ` [dpdk-dev] [PATCH v7 15/17] net/mlx5: validation of CT item Bing Zhao
2021-05-05 12:23   ` [dpdk-dev] [PATCH v7 16/17] net/mlx5: add support of CT between two ports Bing Zhao
2021-05-05 12:23   ` [dpdk-dev] [PATCH v7 17/17] doc: update mlx5 support for conntrack Bing Zhao
2021-05-05 18:21     ` Ferruh Yigit
2021-05-18 13:05       ` Bing Zhao
2021-05-05 17:35   ` [dpdk-dev] [PATCH v7 00/17] conntrack support in mlx5 PMD Raslan Darawsheh

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20210505065008.30680-17-bingz@nvidia.com \
    --to=bingz@nvidia.com \
    --cc=dev@dpdk.org \
    --cc=matan@nvidia.com \
    --cc=orika@nvidia.com \
    --cc=rasland@nvidia.com \
    --cc=thomas@monjalon.net \
    --cc=viacheslavo@nvidia.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).